@@ -4,7 +4,7 @@
 # Object: compare 2 output files from ABINIT line by line with arithmetic
 # comparisons of floating point substrings
 #
-# Copyright (C) 1999-2007 ABINIT group (LSi,XG)
+# Copyright (C) 1999-2009 ABINIT group (LSi,XG)
 # This file is distributed under the terms of the
 # GNU General Public License, see ~abinit/COPYING
 # or http://www.gnu.org/copyleft/gpl.txt .
@@ -388,8 +388,8 @@ sub strfltrem {
   $fltnum = '';
   $remainder = '';
   while (1) {
-# split string into non-numeric and sign-digit substrings
-    $hit = m/([^0-9\-\+]*)(.*$)/;
+# split string into non-numeric and sign-dot-digit substrings
+    $hit = m/([^0-9\-\+\.]*)(.*$)/;
     die "internal error 1" if (! $hit);	# assert
     $nafstr .= $1;		# concatene non-numeric substring
     print 'NAF1:',$1,$nafstr if ($debug >= 2);
