@@ -1,7 +1,7 @@
 # Script for running various tests of abinip, the parallel version of abinit
 # Before running this script, read README in this directory.
 
-# Copyright (C) 1998-2007 ABINIT group (XG,LSi)
+# Copyright (C) 1998-2009 ABINIT group (XG,LSi)
 # This file is distributed under the terms of the
 # GNU General Public License, see ~abinit/COPYING
 # or http://www.gnu.org/copyleft/gpl.txt .
@@ -44,7 +44,8 @@ $PERL = $ENV{'PERL'};
 $, = ' ';               # set output field separator
 $\ = "\n";              # set output record separator
 #
-@MachList = ('t3e','sgi','ibm_pcpm','tux','vpp','hp','compaq_es40','ibm_44p','sr8k','sun','cox','dummy','test','spinoza','boop','sleepy','fock','max','chpit','lemaitre');
+@MachList=('t3e','sgi','tux','vpp','hp','compaq_es40','ibm_44p','sr8k','mpd','sun','dummy','test','spinoza','fock','max','chpit','lemaitre','sleepy(-compilo)','pwrg4','mpich2','generic','chum(-compilo)', 'cea', 'bigmac','green');
+@CompiloList = ('g95','pgi','gcc41','gcc42','gcc43','pathscale','intel','intel10','open64','sun');
 @Cases = ('0','1','2','4','10');
 $debug = 2;
 # Check whether a machine name is provided
@@ -119,6 +120,8 @@ $LAM = 0;
 $MPICH = 0;
 # List the set of cases for each machine (mask the second characteristics
 # of tests, that may be 0, 1, 2, 4, 10 ; 0, 1 and 2 are always allowed)
+$CASE0 = 1;
+$CASE1 = 1;
 $CASE2 = 1;
 $CASE4 = 1;
 $CASE10 = 1;
@@ -134,26 +137,6 @@ elsif ($MACH eq 'sgi') {
   $MPIRUN_NP = 'mpprun -np';
 	}
 #-----------------------------------
-# For hilbert and fermi (IBM Power2, with lam mpi) at the PCPM lab
-elsif ($MACH eq 'ibm_pcpm') {
-  print ' ***** DO NOT FORGET source ~/.cshrc ****** ';
-  $LAM = 1;
-  $LAMDIR = '/usr/local/lam/bin';
-  $MPIRUN_NP = "$LAMDIR/mpirun -w -c";
-  $MACH1 = 'hilbert';
-  $MACH2 = 'fermi';
-  $CASE4 = 0;
-  $CASE10 = 0;
-  unlink 'cluster1','cluster2';
-	open (FILE,">cluster1") || die "Unable to open FILE cluster1";
-	print FILE $MACH1;
-	close (FILE);
-	open (FILE,">cluster2b") || die "Unable to open FILE cluster2b";
-	print FILE $MACH1;
-	print FILE $MACH2;
-	close (FILE);
-	}
-#-----------------------------------
 # For the cluster of DEC/Linux "tux" machine at the UCL.
 # Note that on this cluster, the local 
 # node (tux0) is used for the first thread. 
@@ -307,8 +290,9 @@ elsif ($MACH eq 'ibm_44p') {
 #-----------------------------------
 # For the IBM Power 5  machine at the PCPM lab, using MPICH
 elsif ($MACH eq 'fock') {
-  $MPICH = 1;
-  $MPICH_DIR = '/usr/local/mpich/bin';
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPICH_DIR = '/usr/local/openmpi/bin';
   $MPIRUN_NP = "$MPICH_DIR/mpirun -np";
   $MACH1 = 'fock';
   $CASE10 = 0;
@@ -357,9 +341,13 @@ elsif ($MACH eq 'hp') {
 	}
 #-----------------------------------
 # For the Hitachi SR8000
-elsif ($MACH eq 'sr8k') {
+elsif ($MACH eq 'sr8k' || $MACH eq 'mpd') {
   $MPIRUN_NP = 'mpiexec -n';
 	}
+# 
+elsif ($MACH eq 'cea') {
+  $MPIRUN_NP = 'cea_mprun -p parallele_128 -n ';
+	}
 #-----------------------------------
 # For the Sun sunfire 2 proc
 elsif ($MACH eq 'sun') {
@@ -397,15 +385,124 @@ elsif ($MACH eq 'dummy') {
         }
 #-----------------------------------
 # For the Intel PC XEON "sleepy" 2 procs (with hyperthreading)
-elsif ($MACH eq 'sleepy') {
+elsif ($MACH =~ /^sleepy-?(.*)/) {
   $MPICH = 1;
+  $MPICH_DIR = "/usr/local/mpi-$1/bin";
+  if ($1 eq '') { $MPICH_DIR = "/usr/local/mpi-ifc9.1-64/bin"; }
+# verify if $MPICH_DIR exists
+  if (! -e $MPICH_DIR ) {
+     print "The $MPICH_DIR folder is not present...";
+     print "Choose among : @CompiloList";
+     exit 15;
+  }
 # Note that one uses the mpirun from PGI, but the one from IFC is OK also ...
-  $MPICH_DIR = '/usr/local/mpi-pgi4/bin';
   $MPIRUN_NP = "$MPICH_DIR/mpirun -np";
   $MACH0='sleepy.pcpm.ucl.ac.be';
   $MACH1='sleepy.pcpm.ucl.ac.be:4';
   $MACH2='sleepy.pcpm.ucl.ac.be:2';
   $CASE10 = 0;
+  unlink 'cluster1','cluster2','cluster4';
+        open (FILE,">cluster1") || die "Unable to open FILE cluster1";
+        print FILE $MACH1;
+        close (FILE);
+        open (FILE,">cluster2") || die "Unable to open FILE cluster2";
+        print FILE $MACH2;
+        close (FILE);
+        open (FILE,">cluster4") || die "Unable to open FILE cluster4";
+        print FILE $MACH1;
+        close (FILE);
+}
+#-----------------------------------
+# For the MacPro Mac OS X Leopard Server "bigmac" with biprocs Quad-Core Xeon 2.6Ghz (6Gb RAM)
+elsif ($MACH eq 'bigmac') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+#  $MPICH_DIR = '/opt/local/lib/openmpi/bin';
+  $MPICH_DIR = '/opt/local/openmpi-gcc43_m64/bin';
+  $MPIRUN_NP = "$MPICH_DIR/mpirun -np";
+  $MACH0='bigmac';
+  $MACH1='bigmac';
+  $MACH2='bigmac:2';
+  $MACH3='bigmac:4';
+  $CASE10 = 0;
+  unlink 'cluster1','cluster2','cluster4';
+        open (FILE,">cluster1") || die "Unable to open FILE cluster1";
+        print FILE $MACH1;
+        close (FILE);
+        open (FILE,">cluster2") || die "Unable to open FILE cluster2";
+        print FILE $MACH2;
+        close (FILE);
+        open (FILE,">cluster4") || die "Unable to open FILE cluster4";
+        print FILE $MACH3;
+        close (FILE);
+        }
+#-----------------------------------
+# For the  DELL cluster "green" with biprocs Quad-Core Xeon 2.6Ghz (8Gb RAM) per node
+elsif ($MACH eq 'green') {
+  $MPICH = 2;
+  $OPENMPI = 1;
+  $MPICH_DIR = '/cvos/shared/apps/openmpi/intel/64/current/bin';
+  $MPIRUN_NP = "$MPICH_DIR/mpirun -np";
+  $MACH0='green';
+  $MACH1='green';
+  $MACH2='green:2';
+  $MACH3='green:4';
+  $CASE10 = 0;
+  unlink 'cluster1','cluster2','cluster4';
+        open (FILE,">cluster1") || die "Unable to open FILE cluster1";
+        print FILE $MACH1;
+        close (FILE);
+        open (FILE,">cluster2") || die "Unable to open FILE cluster2";
+        print FILE $MACH2;
+        close (FILE);
+        open (FILE,">cluster4") || die "Unable to open FILE cluster4";
+        print FILE $MACH3;
+        close (FILE);
+        }
+#-----------------------------------
+# For the AMD SUN GALAXY X4200  "chum" 2 x AMD 2220 Dual Cores with OpenMPI or MPICH2
+elsif ($MACH =~ /^chum-?(.*)/) {
+  $MPICH = 2;
+  $OPENMPI = 1;
+#  $MPICH_DIR = "/usr/local/mpich2-$1/bin";
+  $MPICH_DIR = "/usr/local/openmpi-$1/bin";
+  if ($1 eq '') { $MPICH_DIR = "/usr/local/openmpi-intel/bin"; }
+  if ($1 eq 'sun') { $MPICH_DIR = "/usr/local/mpich2-sun/bin"; $OPENMPI = 0;}
+#  if ($1 eq 'open64') { $MPICH_DIR = "/usr/local/mpich2-open64/bin"; $OPENMPI = 0;}
+# verify if $MPICH_DIR exists
+  if (! -e $MPICH_DIR ) {
+     print "The $MPICH_DIR folder is not present...";
+     print "Choose among : @CompiloList";
+     exit 15;
+  }
+print "The $MPICH_DIR will be used...($OPENMPI)";
+#
+  $MPIRUN_NP = "$MPICH_DIR/mpirun -np";
+  $MACH0='chum.pcpm.ucl.ac.be';
+  $MACH1='chum.pcpm.ucl.ac.be:4';
+  $MACH2='chum.pcpm.ucl.ac.be:2';
+  $CASE10 = 0;
+  unlink 'cluster1','cluster2','cluster4';
+        open (FILE,">cluster1") || die "Unable to open FILE cluster1";
+        print FILE $MACH1;
+        close (FILE);
+        open (FILE,">cluster2") || die "Unable to open FILE cluster2";
+        print FILE $MACH2;
+        close (FILE);
+        open (FILE,">cluster4") || die "Unable to open FILE cluster4";
+        print FILE $MACH1;
+        close (FILE);
+}
+#-----------------------------------
+# For the MacBookPRo with Intel 2 cores "pwrg4"
+elsif ($MACH eq 'pwrg4') {
+  $MPICH = 1;
+  $MPICH_DIR = "/usr/local/mpich-1.2.7p1-gcc-4.3.0/bin"; 
+  $MPIRUN_NP = "$MPICH_DIR/mpirun -np";
+  $MACH0='pwrg4.pcpm.ucl.ac.be';
+  $MACH1='pwrg4.pcpm.ucl.ac.be:4';
+  $MACH2='pwrg4.pcpm.ucl.ac.be:2';
+  $CASE10 = 0;
   unlink 'cluster1','cluster2','cluster4';
         open (FILE,">cluster1") || die "Unable to open FILE cluster1";
         print FILE $MACH1;
@@ -444,10 +541,24 @@ elsif ($MACH eq 'max') {
         close (FILE);
         }
 #-----------------------------------
+# For mpich2-1.0.5p4 (gmatteo@tux)
+elsif ($MACH eq 'mpich2') {
+ $MPIRUN_NP = '/opt/mpich2-1.0.5p4/bin/mpirun -np ';
+        }
+#-----------------------------------
+# generic
+# use the mpirun that is in the PATH
+elsif ($MACH eq 'generic') {
+ $MPIRUN_NP = 'mpirun -np ';
+        }
+elsif ($MACH eq 'cea') {
+ $MPIRUN_NP = 'cea_mprun -p parallele_128 -n  ';
+        }
+#-----------------------------------
 # This is a dummy machine name, for sequential tests only
 # (One should check that this is only used in the sequential case)
 elsif ($MACH eq 'test') {
-  $MPIRUN_NP = ' ';
+ $MPIRUN_NP = ' ';
         }
 #-----------------------------------
 else {
@@ -461,38 +572,44 @@ print "Testing the Abinit code on the $MACH $OStype platform";
 # and the definition of their characteristics
 #*******************************************************************************
 $_ = $ARGV[1];
-$hitnum = m/[A-N]/;	# check for upper case
-$hitrng = m/([A-N])-(.*)/;	# check for range
-if ($hitrng) {
-	$FirstSet = $1;
-	$LastSet = $2;
-	$LastSet = 'N' if ($LastSet eq 'end');
-	}
-elsif ($hitnum) {	# if last set is omitted, run only first one
-	$FirstSet = $ARGV[1];
-	$LastSet = $ARGV[1];
-	}
+$hitreport = m/report/;     # check for the keyword report
+if ($hitreport) {
+        print "Will make report";
+        }
 else {
-	print "Invalid sets: $ARGV[1]";
-	exit 24;
-	}
+        $hitnum = m/[A-Y]/;	# check for upper case
+        $hitrng = m/([A-Y])-(.*)/;	# check for range
+        if ($hitrng) {
+	        $FirstSet = $1;
+	        $LastSet = $2;
+	        $LastSet = '' if ($LastSet eq 'end');
+	        }
+        elsif ($hitnum) {	# if last set is omitted, run only first one
+	        $FirstSet = $ARGV[1];
+	        $LastSet = $ARGV[1];
+	        }
+        else {
+	        print "Invalid sets: $ARGV[1]";
+	        exit 24;
+	        }
 
 # set label for default first and last test number
-$FirstCase = '0';
-$LastCase = '10';
-$_ = $ARGV[2];
-$hit = m/(.*)-(.*)/;	# check for range
-	if ($hit) {
-		$FirstCase = $1;
-		$LastCase = $2;
-		$LastCase = '10' if ($LastCase eq 'end');
-		}
-	elsif ($ARGV[2] ne '') {	# if last test is omitted, run only first one
-		$FirstCase = $ARGV[2];
-		$LastCase = $ARGV[2];
-		}
+        $FirstCase = '0';
+        $LastCase = '10';
+        $_ = $ARGV[2];
+        $hit = m/(.*)-(.*)/;	# check for range
+	        if ($hit) {
+		        $FirstCase = $1;
+		        $LastCase = $2;
+		        $LastCase = '10' if ($LastCase eq 'end');
+		        }
+	        elsif ($ARGV[2] ne '') {	# if last test is omitted, run only first one
+		        $FirstCase = $ARGV[2];
+		        $LastCase = $ARGV[2];
+		        }
 
-print "Following tests will be run: sets $FirstSet to $LastSet, cases $FirstCase to $LastCase";
+        print "Following tests will be run: sets $FirstSet to $LastSet, cases $FirstCase to $LastCase";
+        }
 
 #################################################
 # set a date flag to make a new directory today #
@@ -513,9 +630,15 @@ else {
 print "cd $WORK_DIR";
 chdir ("$WORK_DIR");
 
+if ($hitreport) {
+        print "Make report";
+        &doreport();
+        exit 0;
+        }
+
 # **************************************** 
 # Loop on all the sets
-for ($T1 = $FirstSet; $T1 <= $LastSet; $T1 ++) {
+for ($T1 = $FirstSet; $T1 le $LastSet; $T1 ++) {
 # Make preliminary operations that might differ for different tests
 
 # HERE, the set of possible tests and corresponding input file
@@ -530,6 +653,7 @@ for ($T1 = $FirstSet; $T1 <= $LastSet; $T1 ++) {
 #
 	elsif ($T1 eq 'D') {
 	  $PSP1 = "$PSPS/42mo.pspnc";
+          $CASE10=0;
 	  }
 #
 	elsif ($T1 eq 'E' || $T1 eq 'H' || $T1 eq 'J') {
@@ -558,6 +682,7 @@ for ($T1 = $FirstSet; $T1 <= $LastSet; $T1 ++) {
 	elsif ($T1 eq 'I') {
 	  $PSP1 = "$PSPS/26fe.pspnc";
 	  $OPTFLDIFF = '-easy';
+          $CASE10=0;
 	  }
 #
         elsif ($T1 eq 'K') {
@@ -578,7 +703,59 @@ for ($T1 = $FirstSet; $T1 <= $LastSet; $T1 ++) {
         elsif ($T1 eq 'N') {
           $PSP1 = "$PSPS/14si.pspnc";
           }
-
+#
+        elsif ($T1 eq 'O') {
+          $PSP1 = "$PSPS/14si.pspnc";
+          $CASE10=0;
+          }
+#This is to test MPI and paral_kgb, only with 4 procs in parallel
+        elsif ($T1 eq 'P') {
+          $PSP1 = "$PSPS/14si.phoney_mod";
+          $OPTFLDIFF = '-easy';
+          $CASE1= 0;
+          $CASE2= 0;
+          $CASE10=0;
+          }
+#This is to test MPI_IO norm conserving (with the MPI flag), only with 4 procs in parallel
+        elsif ($T1 eq 'Q') {
+          $PSP1 = "$PSPS/14si.phoney_mod";
+	  $CASE0= 0;
+	  $CASE1= 0;
+	  $CASE2= 0;
+	  $CASE10=0;
+          }
+#This is to test MPI and paral_kgb, only with 4 procs in parallel, paw case
+        elsif ($T1 eq 'R') {
+          $PSP1 = "$PSPS/6c_lda.paw";
+          $OPTFLDIFF = '-easy';
+          $CASE1= 0;
+          $CASE2= 0;
+          $CASE10=0;
+          }
+#This is to test MPI_IO PAW (with the MPI flag), only with 4 procs in parallel
+        elsif ($T1 eq 'S') {
+          $PSP1 = "$PSPS/6c_lda.paw";
+	  $CASE0= 0;
+	  $CASE1= 0;
+	  $CASE2= 0;
+	  $CASE10=0;
+          }
+#This is to test the recursion code, in sequential and with 4 procs in parallel
+        elsif ($T1 eq 'T') {
+          $PSP1 = "$PSPS/2he.psphgh";
+	  $CASE1= 0;
+	  $CASE2= 0;
+	  $CASE10=0;
+          }
+#This is to test the KSS generation parallelized over k-points
+        elsif ($T1 eq 'U') {
+          $PSP1 = "$PSPS/14si.pspnc";
+          $CASE10=0;
+          }
+#This is to test the SC-GW with advanced memory management in parallel
+        elsif ($T1 eq 'V') {
+          $PSP1 = "$PSPS/11na.pspnc";
+          }
 	$FLDreport = "fldiff.set$T1.report";
 	unlink $FLDreport;
 	$RUNfile = 'abfiles.run';
@@ -590,6 +767,28 @@ for ($T1 = $FirstSet; $T1 <= $LastSet; $T1 ++) {
 		print $cmd if ($debug > 1);
 		system($cmd);
 		}
+#This is to test MPI and paral_kgb, only with 4 procs in parallel, paw case
+        elsif ($T1 eq 'W') {
+          $PSP1 = "$PSPS/6c_lda.paw";
+          $OPTFLDIFF = '-easy';
+          $CASE1= 0;
+          $CASE2= 0;
+          $CASE10=0;
+          }
+#This is to test the triple BandFFT-kpt parallelization in sequential and on 4 procs in parallel
+        elsif ($T1 eq 'X') {
+          $PSP1 = "$PSPS/6c_lda.paw";
+	  $CASE1= 0;
+	  $CASE2= 0;
+	  $CASE10=0;
+          }
+#Same as X with also test on spin component parallelization, bandpp, istwfk=2 and wfoptalg=14.  
+        elsif ($T1 eq 'Y') {
+          $PSP1 = "$PSPS/6c_lda.paw";
+	  $CASE1= 0;
+	  $CASE2= 0;
+	  $CASE10=0;
+          }
 	
 # ****************************************
 	foreach $case (@Cases) {
@@ -598,8 +797,9 @@ for ($T1 = $FirstSet; $T1 <= $LastSet; $T1 ++) {
 #
 #Here, set characteristics of the test : the name of the test_case is $T1$T2 
 		$T2 = $case;
-		if ( ($T2 eq '2' && $CASE2 == 0) || ($T2 eq '4' && $CASE4 == 0) || 
-				($T2 eq '10' && ($CASE10 == 0 || $T1 eq 'D' || $T1 eq 'I' ) ) ) {
+		if ( ($T2 eq '0' && $CASE0 == 0) || ($T2 eq '1' && $CASE1 == 0) || 
+                     ($T2 eq '2' && $CASE2 == 0) || ($T2 eq '4' && $CASE4 == 0) || 
+		     ($T2 eq '10' && $CASE10 == 0) ) {
 			last if ($T2 eq $LastCase); 
 			next;
 			}
@@ -629,12 +829,19 @@ for ($T1 = $FirstSet; $T1 <= $LastSet; $T1 ++) {
 		else {
 			$MachFile = '';
 			}
-#
+# if not OPENMPI, start mpd (MPICH2)
+		if ($OPENMPI == 0) {
+			$MPDSTAT=`$MPICH_DIR/mpdtrace`;
+			if ( $MPDSTAT =~ !/^chum/ ) {
+        			system("$MPICH_DIR/mpd &");
+			}
+		}
+
 		if ($LAM == 1 && $MODE eq 'PAR') { 
 			$cmd = "$LAMDIR/lamboot $CLUST ";
 			print $cmd if ($debug > 1);
 			system($cmd);
-			}
+		}
 #
 		if ($MODE eq 'SEQ') {
 			$CALL_CODE = ($T2 eq '0' && $MACH eq 'sr8k') ? "prun $CODE_SEQ" : $CODE_SEQ
@@ -695,3 +902,119 @@ sub perlpath {
 	$path =~ tr/\057/\\/ if ($PERLSLASH eq '\\');
 	return $path;
 	}
+# ****************************************
+sub doreport {
+        local($TID) = @_;
+#
+# purpose: exercise lwf
+# arguments:
+#               $TID = test identification (1 to 3 characters string) that will be used as suffix to diff
+# and prefix to log file names
+#               $p1,..$p5 = 1 to 5 parameters [re]defining some option or the file names (fn1 to fn4) that
+# will be put into the "files" file named "lwf.run";
+# the parameter format for a file name is: fnI=path
+# the parameter format for an option is: opt=option ; see setfnopt
+#       $fn1 = main input to lwf
+# $fn2 = moldyn input to lwf
+# $fn3 = output file name that will be compared with reference.
+# $fn4 = auxiliary output file name
+# set default files names derived from $TID:
+# Prepare filenames
+        $fn1 = "$abinit_inpdir/paral/Input/report.in";
+        $reportref = &transpath($fn1);
+        $fn2 = "fldiff.*.report" ;
+        $fldiffreport = &transpath($fn2);
+        $fn3 = "summaryfldiff" ;
+        $summaryfldiff = &transpath($fn3);
+        $fn4 = "report" ;
+        $shortreport = &transpath($fn4);
+# Create summary of tests
+        unlink($summaryfldiff);
+        system ("grep --no-filename 'Summary' $fldiffreport > $summaryfldiff");
+# Compare with reference files
+        print "Prepare the short report";
+        unlink($shortreport);
+        &reportdiff("$summaryfldiff","$reportref","$shortreport");  # compare floating point numbers
+        return;                 # go read next line from configuration file
+        }
+
+# ****************************************
+sub reportdiff {
+        local($fn1,$fn2,$fn3) = @_;
+#
+# purpose : examine $fn1, using the reference values in $fn2, and echo result in $fn3
+#
+        $rc = open(FILEIN,"$fn1");
+        if ($rc eq '') {
+         print "Unable to open input file $fn1\n";
+         }
+        $rc = open(FILEREF,"$fn2");
+        if ($rc eq '') {
+         print "Unable to open input file $fn2\n";
+         }
+        $rc = open (FILEOUT,">>$fn3");
+        if ($rc eq '') {
+         print "Unable to open input file $fn2\n";
+         }
+#       Read both files, one line at a time
+        $lnm1 = 0;
+        $lnm2 = 0;
+        while (1) {
+          $lin1 = <FILEIN>  ;   # read next line from file 1
+          $lin2 = <FILEREF> ;   # read next line from file 2
+          last if($lin1 eq '' && $lin2 eq ''); # end of both files
+          @field1 = split(' ',$lin1);       # parse line into array
+          @field2 = split(' ',$lin2);
+          if ($field1[0] ne 'Summary') {
+            print FILEOUT "Error : all lines of file to be analysed must start with 'Summary' " ;
+            print FILEOUT "Analysed file  $fn1, line $lnm1, gives :" ;
+            print FILEOUT "$lin1" ;
+            print FILEOUT "$field1[0]" ;
+            print FILEOUT "exit" ;
+            exit ;
+            }
+          if ($field1[1] ne $field2[0]) {
+            print FILEOUT "Error : indices of cases do not match in analysed and reference files " ;
+            print FILEOUT "Analysed file  $fn1, line $lnm1, gives $field1[1] ;" ;
+            print FILEOUT "Reference file $fn2, line $lnm2, gives $field2[0] ;" ;
+            print FILEOUT "exit" ;
+            exit ;
+            }
+          if ($field1[3] eq "fatal") {
+            print FILEOUT "$field1[1]            failed" ;
+            }
+          elsif ($field1[3] eq "no") {
+            print FILEOUT "$field1[1] succeeded" ;
+            }
+          elsif ($field1[3] eq "different") {
+            $tolnlines = $field2[2] ;
+            $tolabs = $field2[4] ;
+            $tolrel = $field2[6] ;
+            if ( $field1[10] > $tolabs*1.5 ) {
+              print FILEOUT "$field1[1]            failed (too large absolute error : $field1[10] , accepted $tolabs ) " ;
+              }
+            elsif ( $field1[13] > $tolrel*1.5 ) {
+              print FILEOUT "$field1[1]            failed (too large relative error : $field1[13] , accepted $tolrel ) " ;
+              }
+            elsif ( $field1[5] > $tolnlines ) {
+              print FILEOUT "$field1[1]            failed (too many erroneous lines : $field1[5] , accepted $tolnlines ) " ;
+              }
+            elsif ( $field1[10] > $tolabs ) {
+              print FILEOUT "$field1[1] within 1.5 of tolerance (absolute error : $field1[10] , accepted $tolabs ) " ;
+              }
+            elsif ( $field1[13] > $tolrel ) {
+              print FILEOUT "$field1[1] within 1.5 of tolerance (relative error : $field1[13] , accepted $tolrel ) " ;
+              }
+            else {
+              print FILEOUT "$field1[1] passed" ;
+              }
+            }
+          }
+        close (FILEIN);
+        close (FILEREF);
+        close (FILEOUT);
+        return;                 # go read next line from configuration file
+        }
+
+# ****************************************
+
