@@ -6,7 +6,7 @@
 # v1, v2, ... directories.
 # Before running this script, read README in this directory.
 
-# Copyright (C) 2004-2007 ABINIT group (LSi)
+# Copyright (C) 2004-2009 ABINIT group (LSi)
 # This file is distributed under the terms of the
 # GNU General Public License, see ~abinit/COPYING
 # or http://www.gnu.org/copyleft/gpl.txt .
@@ -34,9 +34,15 @@ $abinit_cmdpar = $ENV{'abinit_cmdpar'};
 $PERL = $ENV{'PERL'};
 $PERL = 'perl' if ($PERL eq '');
 
+# Timeout support
+# This is required for nightly builds, because e.g. binaries built with ifort 10.0 make
+# the process hang forever when they crash.
+$timeout = $ENV{'timeout'};
+$timeout = '0' if ($timeout eq '');
+
 $, = ' ';               # set output field separator
 $\ = "\n";              # set output record separator
-@Series = ('fast','v1','v2','v3','v4','v5','physics','cpu','tutorial','tutorespfn','etsf_io','etsf_xc','bigdft');
+@Series = ('fast','v1','v2','v3','v4','v5','physics','cpu','tutorial','tutorespfn','etsf_io','etsf_xc','bigdft','wannier90');
 $TestDir = '.';		# default is current directory
 # abinis processing options:
 $optKeepfn4 = 1;	# keep files fn4* after test completion
@@ -61,6 +67,8 @@ if ($ARGV[0] eq '') {
   }
 $MACH = $ARGV[0];
 $abinit_bindir = $ARGV[1];
+# I know, the following is ugly! (YP)
+$abinit_nightlydir = "$abinit_bindir/../nightly";
 $top_testdir = $ARGV[2];
 $argptr = 3;
 # check first argument against some tests serie
@@ -272,23 +280,43 @@ unlink ("$CHKREPORT") if ($rc == 0);    # get rid of file anyway
 
 # define file paths relative to $WORK_DIR in the unix fashion
 # they will be translated by the perlpath/transpath function if necessary
+if ($timeout eq '0') {
+  $timeout_cmd = '';
+  }
+else {
+  $timeout_cmd = &perlpath("$abinit_nightlydir/timeout$XSUFX")." $timeout ";
+}
 $CODE_SEQ = &perlpath("$abinit_bindir/abinis$XSUFX");	# codename for sequential version
+$CODE_SEQ = "$timeout_cmd$CODE_SEQ";
 $CODE_CPU = &perlpath("$abinit_bindir/abinis$XSUFX");  # sequential version for cpu tests
+$CODE_CPU = "$timeout_cmd$CODE_CPU";
 $CODE_NEWSP = &perlpath("$abinit_bindir/newsp$XSUFX");	# codename for newsp
+$CODE_NEWSP = "$timeout_cmd$CODE_NEWSP";
 $CODE_MRGDDB = &perlpath("$abinit_bindir/mrgddb$XSUFX");	# codename for mrgddb
+$CODE_MRGDDB = "$timeout_cmd$CODE_MRGDDB";
 $CODE_MRGSCR = &perlpath("$abinit_bindir/mrgscr$XSUFX");	# codename for mrgscr
+$CODE_MRGSCR = "$timeout_cmd$CODE_MRGSCR";
 $CODE_MRGGKK = &perlpath("$abinit_bindir/mrggkk$XSUFX");	# codename for mrggkk
+$CODE_MRGGKK = "$timeout_cmd$CODE_MRGGKK";
 $CODE_ANADDB = &perlpath("$abinit_bindir/anaddb$XSUFX");	# codename for anaddb
+$CODE_ANADDB = "$timeout_cmd$CODE_ANADDB";
 $CODE_CUT3D = &perlpath("$abinit_bindir/cut3d$XSUFX");	# codename for cut3d
+$CODE_CUT3D = "$timeout_cmd$CODE_CUT3D";
 $CODE_AIM = &perlpath("$abinit_bindir/aim$XSUFX");	# codename for atom-in-molecule (aim) code
+$CODE_AIM = "$timeout_cmd$CODE_AIM";
 $CODE_CONDUCTI = &perlpath("$abinit_bindir/conducti$XSUFX");	# codename for conducti
+$CODE_CONDUCTI = "$timeout_cmd$CODE_CONDUCTI";
 $CODE_OPTIC = &perlpath("$abinit_bindir/optic$XSUFX");	# codename for optic
+$CODE_OPTIC = "$timeout_cmd$CODE_OPTIC";
 $CODE_MACROAVE = &perlpath("$abinit_bindir/macroave$XSUFX");	# codename for macroave
+$CODE_MACROAVE = "$timeout_cmd$CODE_MACROAVE";
 $CODE_LWF = &perlpath("$abinit_bindir/lwf$XSUFX");	# codename for lwf
+$CODE_LWF = "$timeout_cmd$CODE_LWF";
 $CODE_BAND2EPS = &perlpath("$abinit_bindir/band2eps$XSUFX");	# codename for band2eps
-$CODE_CHI = &perlpath("$abinit_bindir/chi$XSUFX");	# codename for chi
-$CODE_PAR = &perlpath("$abinit_cmdpar");	# codename for parallel version WARNING XG051130 DOES NOT WORK
+$CODE_BAND2EPS = "$timeout_cmd$CODE_BAND2EPS";
+#$CODE_PAR = &perlpath("$abinit_cmdpar");	# codename for parallel version WARNING XG051130 DOES NOT WORK
 $CODE_PAR = '/usr/local/mpi-pgi4/bin/mpirun -np 2 -machinefile sleepy.pcpm.ucl.ac.be:2 ../../../src/main/abinip' ;      # run parallel version on sleepy
+$CODE_PAR = "$timeout_cmd$CODE_PAR";
 
 $INPUTDIR = &transpath("$top_testdir/$TestDir/Input");		# input directory
 $REF = &transpath("$top_testdir/$TestDir/Refs");		# reference directory
@@ -879,7 +907,8 @@ sub doanatest {
 	$fn3 = "t$TID.ddb.in";	# t13.ddb.in
 	$fn4 = "t$TID.md";	# t13.md
 	$fn5 = "t$TID.gkk";	# t13.gkk Dummy file for now
-	$fn6 = "t$TID";		# t13  base name
+	$fn6 = "t$TID";		# t13  base name for elphon outputs
+	$fn7 = "$top_testdir/$TestDir/Input/t$TID.ddk";	# ../t13.ddk default name for file containing list of ddk filenames
 # set new file names according to the parameters
 # Added mverstra 29 07 2004
 	for ($i=1;$i <= 5;$i++) {
@@ -915,6 +944,7 @@ sub doanatest {
 	print FILES $fn4;
 	print FILES $fn5;
 	print FILES $fn6;
+	print FILES &transpath($fn7);
 	close(FILES);
 
 	return if ($debug >= 3);
