@@ -1,4 +1,4 @@
-# Copyright (C) 1998-2003 ABINIT group (XG)
+# Copyright (C) 1998-2009 ABINIT group (XG)
 # 
 # The purpose of this script is to change some
 # expression by another in a whole set of files
@@ -8,10 +8,9 @@ for file in "$@"
 do
  echo "working on $file"
  rm -f tmp.file
- sed -e 's&developers/contributors&developers/contributors.txt&' $file > tmp.file
+ sed -e 's&(C) 1996-2008 ABINIT&(C) 1996-2009 ABINIT&' $file > tmp.file
  echo "changes done "
  # put the modified file at the correct place
- mv $file $file.OLD
  mv tmp.file $file
  echo "file $file written "
 done
