@@ -6,7 +6,7 @@ echo "Looking for orphan files"
 echo "------------------------"
 echo ""
 
-for d in lib/[a-z]* src/defs src/[0-9]*
+for d in prereqs/[a-z]* plugins/[a-z]* src/defs src/[0-9]*
 do
 	orphans=""
 
